eric7/Unittest/Interfaces/UTExecutorBase.py

branch
unittest
changeset 9063
f1d7dd7ae471
parent 9062
7f27bf3b50c3
child 9064
339bb8c8007d
--- a/eric7/Unittest/Interfaces/UTExecutorBase.py	Fri May 13 17:23:21 2022 +0200
+++ b/eric7/Unittest/Interfaces/UTExecutorBase.py	Sat May 14 18:56:52 2022 +0200
@@ -33,16 +33,17 @@
     """
     Class containing the test result data.
     """
-    category: ResultCategory    # result category
-    status: str                 # test status
-    name: str                   # test name
-    id: str                     # test id
-    description: str = ""       # short description of test
-    message: str = ""           # short result message
-    extra: list = None          # additional information text
-    duration: float = None      # test duration
-    filename: str = None        # file name of a failed test
-    lineno: int = None          # line number of a failed test
+    category: ResultCategory        # result category
+    status: str                     # test status
+    name: str                       # test name
+    id: str                         # test id
+    description: str = ""           # short description of test
+    message: str = ""               # short result message
+    extra: list = None              # additional information text
+    duration: float = None          # test duration
+    filename: str = None            # file name of a failed test
+    lineno: int = None              # line number of a failed test
+    subtestResult: bool = False     # flag indicating the result of a subtest
 
 
 @dataclass
@@ -50,14 +51,14 @@
     """
     Class containing the test run configuration.
     """
-    interpreter: str            # path of the Python interpreter
-    discover: bool              # auto discovery flag
-    discoveryStart: str         # start directory for auto discovery
-    testFilename: str           # name of the test script
-    testName: str               # name of the test function
-    failFast: bool              # stop on first fail
-    collectCoverage: bool       # coverage collection flag
-    eraseCoverage: bool         # erase coverage data first
+    interpreter: str                # path of the Python interpreter
+    discover: bool                  # auto discovery flag
+    discoveryStart: str             # start directory for auto discovery
+    testFilename: str               # name of the test script
+    testName: str                   # name of the test function
+    failFast: bool                  # stop on first fail
+    collectCoverage: bool           # coverage collection flag
+    eraseCoverage: bool             # erase coverage data first
 
 
 class UTExecutorBase(QObject):

eric ide

mercurial